#include  <Trade\AccountInfo.mqh>
#include  <Trade\DealInfo.mqh>
#include  <Trade\HistoryOrderInfo.mqh>
#include  <Trade\OrderInfo.mqh>
#include  <Trade\PositionInfo.mqh>
#include  <Trade\SymbolInfo.mqh>
#include  <Trade\TerminalInfo.mqh>
#include  <Trade\Trade.mqh>
//+------------------------------------------------------------------+
class CFixTrader
{
private:
   CAccountInfo      *mp_CAccountInfo;
   CDealInfo         *mp_CDealInfo;
   CHistoryOrderInfo *mp_CHistoryOrderInfo;
   COrderInfo        *mp_COrderInfo;
   CPositionInfo     *mp_CPositionInfo;
   CSymbolInfo       *mp_CSymbolInfo;
   CTerminalInfo     *mp_CTerminalInfo;
   CTrade            *mp_CTrade;
   
   static
   string mswas_FIX_Symbols[];
   int    ms32_FIX_SymbolsTotal;
   
   string mswa_SymbolsTotal[];
   int    ms32_SymbolsTotal;  
   
   string msw_SymbolToTrade;
   string msw_SymbolToTradeFIX_Quote;
   
   string msw_EA_Name;
   bool   mb_Initialized;
   
   void TradeSetUp();
   void SymbolsTotalGet();
public:
   CFixTrader();
  ~CFixTrader();
   bool InitAndCheckParms();
   void Run();
};
//+------------------------------------------------------------------+
CFixTrader::CFixTrader()
{
   mp_CAccountInfo  = new CAccountInfo();
   mp_CSymbolInfo   = new CSymbolInfo();
   mp_COrderInfo    = new COrderInfo();
   mp_CPositionInfo = new CPositionInfo();
   mp_CTrade        = new CTrade();
   
   ms32_FIX_SymbolsTotal = ArraySize(mswas_FIX_Symbols);
   
   SymbolsTotalGet();
   ms32_SymbolsTotal = ArraySize(mswa_SymbolsTotal);
   
   msw_EA_Name    = MQL5InfoString(MQL5_PROGRAM_NAME);
   mb_Initialized = false;
}
//+------------------------------------------------------------------+
CFixTrader::~CFixTrader()
{
   delete mp_CAccountInfo;
   delete mp_CSymbolInfo;
   delete mp_COrderInfo;
   delete mp_CPositionInfo;
   delete mp_CTrade;
}
//+------------------------------------------------------------------+
bool CFixTrader::InitAndCheckParms()
{
   if (mp_CAccountInfo.MarginMode() != ACCOUNT_MARGIN_MODE_RETAIL_HEDGING)
   {
      PlaySound("alert.wav");
      Print(msw_EA_Name + " : EA is designed to work only on HEDGING type Accounts ");
      MessageBox(msw_EA_Name + " : EA is designed to work only on HEDGING type Accounts ",  NULL, MB_OK);
      ExpertRemove();
      return(false);
   }
   else
   {
      Print("Account type is HEDGING");
   }
   
   msw_SymbolToTrade = psw_SymbolToTrade;
   
   StringTrimLeft(msw_SymbolToTrade);
   StringTrimRight(msw_SymbolToTrade);
   
   if (msw_SymbolToTrade == "")
      msw_SymbolToTrade = Symbol();
      
   int i;
   for (i = 0; i < ms32_SymbolsTotal; i++)
   {
      if (msw_SymbolToTrade == mswa_SymbolsTotal[i])
         break;
   }   
   if (i == ms32_SymbolsTotal)
   {
      PlaySound("alert.wav");
      Print(msw_EA_Name + " : EA parm psw_SymbolToTrade = " + psw_SymbolToTrade + " is invalid, no such Symbol in terminal ");
      MessageBox(msw_EA_Name + " : EA parm psw_SymbolToTrade = " + psw_SymbolToTrade + " is invalid, no such Symbol in terminal ",  NULL, MB_OK);
      ExpertRemove();
      return(false);
   }
   
   for (i = 0; i < ms32_FIX_SymbolsTotal; i++)
   {
      if (StringFind(msw_SymbolToTrade,mswas_FIX_Symbols[i]) >= 0)
      {
         msw_SymbolToTradeFIX_Quote = mswas_FIX_Symbols[i];
         break;
      }
   }   
   if (i == ms32_FIX_SymbolsTotal)
   {
      PlaySound("alert.wav");
      Print(msw_EA_Name + " : EA parm psw_SymbolToTrade = " + psw_SymbolToTrade + " is invalid, FIX provider has not Quote for this Symbol ");
      MessageBox(msw_EA_Name + " : EA parm psw_SymbolToTrade = " + psw_SymbolToTrade + " is invalid, FIX provider has not Quote for this Symbol ",  NULL, MB_OK);
      ExpertRemove();
      return(false);
   }
   
   PlaySound("ok.wav");
   Print(msw_EA_Name + " EA was successfully launched...");
   mb_Initialized = true;
      
   return(true);
}
//+------------------------------------------------------------------+
void CFixTrader::Run()
{
}
//+------------------------------------------------------------------+
void CFixTrader::SymbolsTotalGet()
{
   ms32_SymbolsTotal = SymbolsTotal(false);
   
   ArrayResize(mswa_SymbolsTotal,ms32_SymbolsTotal);
   
   for (int i = 0; i < ms32_SymbolsTotal; i++)
      mswa_SymbolsTotal[i] = SymbolName(i,false);
}
//+------------------------------------------------------------------+
string CFixTrader::mswas_FIX_Symbols[] =
{
   "AUDCAD",
   "AUDCHF",
   "AUDJPY",
   "AUDNZD",
   "AUDUSD",
   "CADCHF",
   "CADJPY",
   "CHFJPY",
   "EURAUD",
   "EURCAD",
   "EURCHF",
   "EURCZK",
   "EURDKK",
   "EURGBP",
   "EURHKD",
   "EURHUF",
   "EURJPY",
   "EURMXN",
   "EURNOK",
   "EURNZD",
   "EURPLN",
   "EURRUB",
   "EURSEK",
   "EURSGD",
   "EURTRY",
   "EURUSD",
   "EURZAR",
   "GBPAUD",
   "GBPCAD",
   "GBPCHF",
   "GBPCZK",
   "GBPDKK",
   "GBPHKD",
   "GBPHUF",
   "GBPJPY",
   "GBPMXN",
   "GBPNOK",
   "GBPNZD",
   "GBPPLN",
   "GBPSEK",
   "GBPSGD",
   "GBPTRY",
   "GBPUSD",
   "GBPZAR",
   "NOKSEK",
   "NZDCAD",
   "NZDCHF",
   "NZDJPY",
   "NZDSGD",
   "NZDUSD",
   "USDCAD",
   "USDCHF",
   "USDCNH",
   "USDCZK",
   "USDDKK",
   "USDHKD",
   "USDHUF",
   "USDJPY",
   "USDMXN",
   "USDNOK",
   "USDPLN",
   "USDRUB",
   "USDSEK",
   "USDSGD",
   "USDTRY",
   "USDZAR",
   "WTIUSD",
   "XAGAUD",
   "XAGUSD",
   "XAUAUD",
   "XAUEUR",
   "XAUUSD",
   "XBRUSD",
   "XPDUSD",
   "XPTUSD"
};
